@@ -16,9 +16,9 @@ def NameField(**kwargs):
         unique=unique,
         validators=(
             validators.RegexValidator(
-                regex=r"^[a-zA-Z0-9\- ()ßàÀéÉèÈäÄëËïÏöÖüÜçÇâÂêÊîÎôÔûÛ']*$",
+                regex=r"^[a-zA-Z0-9\-_ ()ßàÀéÉèÈäÄëËïÏöÖüÜçÇâÂêÊîÎôÔûÛ']*$",
                 message="Allowed characters: "
-                """"a-z", "A-Z", "0-9", "-", "(", ")", "'", """
+                """"a-z", "A-Z", "0-9", "-", "_", "(", ")", "'", """
                 "spaces and diacritics.",
             ),
         ),
